package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.serializer.MapSerializer;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.mapper.AmsshipCargoTransferResultMapper;
import com.steerinfo.dil.mapper.DilBatchMapper;
import com.steerinfo.dil.model.AmsshipCargoTransferResult;
import com.steerinfo.dil.model.AmsshipDeliveryAttorney;
import com.steerinfo.dil.model.DilBatch;
import com.steerinfo.dil.model.OmsshipShipmentInstructions;
import com.steerinfo.dil.service.IAmsshipCargoTransferResultService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import oracle.jdbc.proxy.annotation.Post;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.math.BigDecimal;
import java.util.Map;

/**
 * AmsshipCargoTransferResult RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-18 03:36
 * 类描述
 * 修订历史：
 * 日期：2021-08-18
 * 作者：generator
 * 参考：
 * 描述：AmsshipCargoTransferResult RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amsshipcargotransferresults")
public class AmsshipCargoTransferResultController extends BaseRESTfulController {

    @Autowired
    IAmsshipCargoTransferResultService amsshipCargoTransferResultService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    DilBatchMapper dilBatchMapper;
    @Autowired
    AmsshipCargoTransferResultMapper amsshipCargoTransferResultMapper;
    @Autowired
    ESFeign esFeign;

    @ApiOperation(value = "展示货权转移表", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "66", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getAmsshipCargoTranferResultList")
    public RESTfulResult getAmsshipCargoTranferResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          Integer apiId) {
        //初始化过滤
        List<Map<String, Object>> listTotal = amsshipCargoTransferResultService.seletCargoTransfer(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsshipCargoTransferResultService.seletCargoTransfer(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

//    //新增
//    @ApiOperation(value = "新增", notes = "根据amsshipCargoTransferResult对象创建")
//    @ApiImplicitParam(name = "amsshipCargoTransferResult", value = "详细实体amsshipCargoTransferResult", required = true, dataType = "amsshipCargoTransferResult", paramType = "java.util.Map")
//    @PostMapping(value = "/insertamsshipCargoTransferResult")
//    public RESTfulResult insertamsshipCargoTransferResult(@RequestBody(required = false) Map<String, Object> map) {
//        int code = amsshipCargoTransferResultService.addCargoTransferResult(map);
//        return success(code);
//    }

    //根据id获取信息
    @ApiOperation(value = "获取详细信息", notes = "根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/selectByCargoTranferResultId/{cargoTransferResultId}")
    public RESTfulResult selectByCargoTranferResultId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
     Map<String, Object> amsshipCargoTransferResult = amsshipCargoTransferResultService.selectByOrder(cargoTransferResultId);
        return success(amsshipCargoTransferResult);
    }




    //修改
    @ApiOperation(value = "更新详细信息", notes = "根据url的id来指定更新对象，并根据传过来的amsshipDeliveryAttorney信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "amsshipDeliveryAttorney", value = "详细实体amsshipDeliveryAttorney", required = true, dataType = "amsshipDeliveryAttorney")
    })
    @PostMapping(value = "/editCargoTransferResult", produces = "application/json;charset=UTF-8")
    public RESTfulResult editCargoTransferResult(@RequestBody Map<String,Object> map) {
        int i= amsshipCargoTransferResultService.update(map);
        return success(i);
    }

    //删除
    @ApiOperation(value = "删除", notes = "根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/deleteByCargoId/{cargoTransferResultId}")//BigDecimal
    public RESTfulResult deleteByCargoId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        System.out.println(cargoTransferResultId);
        AmsshipCargoTransferResult amsshipCargoTransferResult = new AmsshipCargoTransferResult();
        amsshipCargoTransferResult.setCargoTransferResultId(new BigDecimal(cargoTransferResultId));
        BigDecimal deleted = new BigDecimal(1);
        amsshipCargoTransferResult.setDeleted(deleted);
        amsshipCargoTransferResultService.updateByPrimaryKeySelective(amsshipCargoTransferResult);
        //删除批次
        //根据货权转移id查找批次id
        Map<String, Object> map = amsshipCargoTransferResultMapper.getBatchIdByCargoTransferResultId(DataChange.dataToBigDecimal(cargoTransferResultId));
        BigDecimal batchId =DataChange.dataToBigDecimal(map.get("batchId"));
        int i = dilBatchMapper.deleteByPrimaryKey(batchId.shortValue());
        return success(i);
    }

    //得到收货人id
    @ApiOperation(value = "获取详细信息", notes = "根据url的id来获取详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "apiId", value = "217", required = true, dataType = "int")
    })

    @PostMapping(value = "/getGroupList")
    public RESTfulResult getGroupList(@RequestBody(required = false) Map<String, Object> mapValue,
                                      Integer pageNum,
                                      Integer pageSize,
                                      Integer apiId,
                                      String con) {

        {
             if (con!=null&&!con.equals("null")){
                 mapValue.put("con","%"+con+"%");
             }
            //初始化过滤
            List<Map<String, Object>> listTotal = amsshipCargoTransferResultService.getGroup(mapValue);
            PageHelper.startPage(pageNum, pageSize);
            //分页查询数据
            List<Map<String, Object>> columnList = amsshipCargoTransferResultService.getGroup(mapValue);
            PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
            return success(data);
        }
    }

    //得到货物id
    @ApiOperation(value = "获取详细信息", notes = "根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @GetMapping(value = "/getCargoId")
    public RESTfulResult getCargoId() {
        List<Map<String, Object>> list = amsshipCargoTransferResultService.getCargoId();
        return success(list);
    }

    //得到批次id
    @ApiOperation(value = "获取详细信息", notes = "根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @GetMapping(value = "/insertBetchId")
    public RESTfulResult insertBetchId() {
        List<Map<String, Object>> list = amsshipCargoTransferResultService.insertBetchId();
        return success(list);
    }

    //获取物资id
    @ApiOperation(value = "获取详细信息", notes = "根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "apiId", name = "apiI", value = "216", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getMaterialList")
    public RESTfulResult getMaterialList(@RequestBody(required = false) Map<String, Object> map,
                                            String con,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize
    ) {
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_material_name";
                //获取查询结果
                return success(esFeign.getConResult(map, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (map.size() == 0) {
            //将查询结果存入索引中
            listTotal = amsshipCargoTransferResultService.selectMaterialId(null);
            Map<String, Object> map1 = new HashMap<>();
            //添加索引
            map1.put("index", "get_material_name");
            //添加id
            map1.put("indexId", "materialId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = amsshipCargoTransferResultService.selectMaterialId(map);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsshipCargoTransferResultService.selectMaterialId(map);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    //获取货权转移送达单位
    @ApiOperation(value = "获取货权转移送达单位")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "215", dataTypeClass = String.class, required = true)
    })
    @PostMapping("/selectShippeByName")
    public RESTfulResult selectShippeByName(@RequestBody(required = false) Map<String, Object> map,
                                            String con,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize
    ) {
        List<Map<String, Object>> listTotal = amsshipCargoTransferResultService.selectShipperName(map);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsshipCargoTransferResultService.selectShipperName(map);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    @ApiOperation(value = "收货单位")
    @GetMapping("/getGroupId")
    public RESTfulResult getGroupId() {
        List<Map<String,Object>> data = amsshipCargoTransferResultService.getGroup(null);
        return success(data);
    }



}