package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.OmsshipInstructionsCapacity;
import com.steerinfo.dil.model.OmsshipShipmentInstructions;
import com.steerinfo.dil.model.TmsshipBargeOperation;
import com.steerinfo.dil.service.IOmsshipInstructionsCapacityService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.math.BigDecimal;

/**
 * OmsshipInstructionsCapacity RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-20 03:06
 * 类描述
 * 修订历史：
 * 日期：2021-08-20
 * 作者：generator
 * 参考：
 * 描述：OmsshipInstructionsCapacity RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/omsshipinstructionscapacitys")
public class OmsshipInstructionsCapacityController extends BaseRESTfulController {

    @Autowired
    IOmsshipInstructionsCapacityService omsshipInstructionsCapacityService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;
    /**
     * 获取运单id
     * @return
     */
    @GetMapping("getOrderId")
    @ApiOperation(value = "获取运单id下拉列表")
    public RESTfulResult getTask(){
        return success(omsshipInstructionsCapacityService.getOrderId());
    }

    /**
     * 展示船只信息列表
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示船只信息列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "instructionsId", value = "装船指令id", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "76", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getCapacities")
    public RESTfulResult getCapacities(BigDecimal instructionsId,@RequestBody(required = false) Map<String,Object> mapVal,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId){
        if (mapVal==null) {
            mapVal = new HashMap<>();
        }
        mapVal.put("instructionsId",instructionsId);
        List<Map<String,Object>> list = omsshipInstructionsCapacityService.selectCapacities(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = omsshipInstructionsCapacityService.selectCapacities(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 新增
     * @param omsshipInstructionsCapacity
     * @return
     */
    @ApiOperation(value="新增", notes="根据OmsshipInstructionsCapacity对象创建")
    @ApiImplicitParam(name = "omsshipInstructionsCapacity", value = "详细实体omsshipInstructionsCapacity", required = true, dataType = "OmsshipInstructionsCapacity")
    @PostMapping(value = "/addInstructionsCapacity")
    public RESTfulResult addInstructionsCapacity(@RequestBody Map<String,Object> omsshipInstructionsCapacity){
        int code=omsshipInstructionsCapacityService.insert(omsshipInstructionsCapacity);
        return success(code);
    }

    /**
     * 获取发件人id
     * @return
     */
    @GetMapping("getCapacityId")
    @ApiOperation(value = "获取船id下拉列表")
    public RESTfulResult getCapacityId(){
        return success(omsshipInstructionsCapacityService.getCapacityId());
    }

    /**
     * 查询
     * @param instructionsCapacityId
     * @return
     */
    @ApiOperation(value="查询表单信息")
    @ApiImplicitParam(name = "instructionsCapacityId", value = "运单id", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getInstructionsCapacity/{instructionsCapacityId}")
    public RESTfulResult getInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId){
        List<Map<String,Object>> map = omsshipInstructionsCapacityService.selectInstructionsCapacity(instructionsCapacityId);
        return success(map);
    }
    /**
     * 修改船运信息
     * @param omsshipInstructionsCapacity
     * @return
     */
    @ApiOperation(value="修改船运信息", notes="根据OmsshipInstructionsCapacity对象修改")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "omsshipInstructionsCapacity",value = "船运字段",required = true,paramType = "OmsshipInstructionsCapacity")
    })
    @PostMapping("/updateInstructionsCapacity")
    public RESTfulResult updateInstructionsCapacity(@RequestBody OmsshipInstructionsCapacity omsshipInstructionsCapacity) {
        int code = omsshipInstructionsCapacityService.updateByPrimaryKeySelective(omsshipInstructionsCapacity);
        return success(code);
    }

    /**
     * 逻辑删除
     * @param instructionsCapacityId
     * @return
     */
    @ApiOperation(value="逻辑删除", notes="根据instructionsCapacityId删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "instructionsCapacityId",value = "船运字段",required = true,paramType = "BigDecimal")
    })
    @PostMapping("/deleteInstructionsCapacity/{instructionsCapacityId}")
    public RESTfulResult deleteInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId) {
        int code = omsshipInstructionsCapacityService.deleteByPrimaryKey(instructionsCapacityId);
        return success(code);
    }

}
